part of katana_module;

/// Type of form.
enum DateTimeFormConfigType {
  /// Date only.
  date,

  /// Time only.
  time,

  /// Date and time.
  dateTime,
}

/// FormConfig for using date time field.
@immutable
class DateTimeFormConfig extends FormConfig {
  const DateTimeFormConfig({
    this.backgroundColor,
    this.initialDate,
    this.color,
    this.type = DateTimeFormConfigType.dateTime,
  });

  static const String _type = "dateTime";

  final DateTime? initialDate;

  final DateTimeFormConfigType type;

  final Color? backgroundColor;

  final Color? color;

  static DateTimeFormConfig? _fromMap(DynamicMap map) {
    final initialDate = map.get<int?>("initialDate", null);
    return DateTimeFormConfig(
      backgroundColor: map.getAsMap("backgroundColor").toColor(),
      color: map.getAsMap("color").toColor(),
      initialDate: initialDate != null
          ? DateTime.fromMillisecondsSinceEpoch(initialDate)
          : null,
      type: DateTimeFormConfigType.values.firstWhereOrNull((item) =>
              item.index ==
              map.get("dateTimeType", DateTimeFormConfigType.dateTime.index)) ??
          DateTimeFormConfigType.dateTime,
    );
  }

  /// Convert the form config to [DynamicMap].
  @override
  DynamicMap toMap() {
    return <String, dynamic>{
      "type": _type,
      "dateTimeType": type.index,
      "backgroundColor": backgroundColor.toMap(),
      "color": color.toMap(),
      if (initialDate != null)
        "initialDate": initialDate!.millisecondsSinceEpoch,
    };
  }
}
